@@ -1,10 +1,15 @@
+-- |
+-- Module: Data.Conduit.Codec.Base16
+-- Copyright: (c) 2014 Magnus Therning
+-- License: BSD3
 module Data.Conduit.Codec.Base16 where
 
 import qualified Codec.Binary.Base16 as B16
 import qualified Data.Conduit.Codec.Util as U
 
-import Data.Conduit
-import Data.ByteString as BS
+import Control.Monad.Catch (MonadThrow)
+import Data.ByteString (ByteString, empty)
+import Data.Conduit (Conduit)
 
 encode :: (Monad m) => Conduit ByteString m ByteString
 encode = U.encodeII B16.encode
