@@ -20,11 +20,14 @@ case_enc_foobar :: IO ()
 case_enc_foobar = do
     BS.empty          @=? QP.encode BS.empty
     BSC.pack "foobar" @=? QP.encode (BSC.pack "foobar")
+    BSC.pack "foo=20bar" @=? QP.encode (BSC.pack "foo bar")
 
 case_dec_foobar :: IO ()
 case_dec_foobar = do
     Right BS.empty            @=? QP.decode BS.empty
     Right (BSC.pack "foobar") @=? QP.decode (BSC.pack "foobar")
+    Right (BSC.pack "foo bar") @=? QP.decode (BSC.pack "foo bar")
+    Right (BSC.pack "foo bar") @=? QP.decode (BSC.pack "foo=20bar")
 
 prop_encdec :: [Word8] -> Bool
 prop_encdec ws = (BS.pack ws) == (fromRight $ QP.decode $ QP.encode $ BS.pack ws)
