@@ -5,13 +5,7 @@
 
 module Main where
 
-import Test.Framework
-import Test.Framework.TH
--- import Test.Framework.Providers.HUnit
--- import Test.Framework.Providers.QuickCheck2
--- import Test.HUnit
--- import qualified Data.ByteString as BS
--- import qualified Data.ByteString.Char8 as BSC
+import Test.Tasty
 
 import qualified Codec.Binary.Base16Test as B16Test
 import qualified Codec.Binary.Base32Test as B32Test
@@ -24,10 +18,9 @@ import qualified Codec.Binary.UuTest as UuTest
 import qualified Codec.Binary.XxTest as XxTest
 import qualified Codec.Binary.YencTest as YTest
 
-tests :: [Test.Framework.Test]
-tests =
-    [ $(testGroupGenerator)
-    , B16Test.tests
+tests :: TestTree
+tests = testGroup "All tests"
+    [ B16Test.tests
     , B32Test.tests
     , B32HTest.tests
     , B64Test.tests
